export var _isValidEmail = function (email) {
    var emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return emailRegex.test(email);
};
export var _isValidPhoneNumber = function (phoneNumber) {
    var phoneRegex = /^\+?[0-9]{10,15}$/;
    return phoneRegex.test(phoneNumber);
};
export var _isValidURL = function (url) {
    var urlRegex = /^(https?:\/\/)?([a-zA-Z0-9.-]+)(:[0-9]{1,5})?(\/.*)?$/;
    return urlRegex.test(url);
};
export var _isValidDate = function (date) {
    var dateRegex = /^\d{4}-\d{2}-\d{2}$/;
    return dateRegex.test(date);
};
export var _isValidTime = function (time) {
    var timeRegex = /^([01]\d|2[0-3]):([0-5]\d)$/;
    return timeRegex.test(time);
};
export var _isValidDateTime = function (dateTime) {
    var dateTimeRegex = /^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}$/;
    return dateTimeRegex.test(dateTime);
};
export var _isValidDateRange = function (startDate, endDate) {
    return new Date(startDate) <= new Date(endDate);
};
export var _isValidPassword = function (password) {
    var passwordRegex = /^(?=.*[A-Za-z])(?=.*\d)[A-Za-z\d]{8,}$/;
    return passwordRegex.test(password);
};
export var _isValidUsername = function (username) {
    var usernameRegex = /^[a-zA-Z0-9._-]{3,}$/;
    return usernameRegex.test(username);
};
export var _isValidCreditCard = function (creditCard) {
    var creditCardRegex = /^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6(?:011|5[0-9]{2})[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|7(?:0[0-9]|[1-9][0-9])[0-9]{11}|(?:2131|1800|35\d{3})\d{11})$/;
    return creditCardRegex.test(creditCard);
};
export var _isValidHexColor = function (color) {
    var hexColorRegex = /^#([0-9A-F]{3}|[0-9A-F]{6})$/i;
    return hexColorRegex.test(color);
};
export var _isValidIP = function (ip) {
    var ipRegex = /^(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
    return ipRegex.test(ip);
};
export var _isValidMacAddress = function (mac) {
    var macRegex = /^([0-9A-F]{2}[:-]){5}([0-9A-F]{2})$/i;
    return macRegex.test(mac);
};
export var _isValidUUID = function (uuid) {
    var uuidRegex = /^[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i;
    return uuidRegex.test(uuid);
};
export var _isValidBase64 = function (str) {
    var base64Regex = /^(?:[A-Z0-9+\/]{4})*=[=]?$/i;
    return base64Regex.test(str);
};
export var _isValidJSON = function (str) {
    try {
        JSON.parse(str);
        return true;
    }
    catch (_a) {
        return false;
    }
};
export var _isValidFunction = function (fn) {
    return typeof fn === 'function';
};
export var _isValidString = function (str) {
    return typeof str === 'string' && str.trim() !== '';
};
export var _isValidNumber = function (num) {
    return typeof num === 'number' && !isNaN(num);
};
export var _isValidBoolean = function (bool) {
    return typeof bool === 'boolean';
};
export var _isValidDateObject = function (date) {
    return date instanceof Date && !isNaN(date.getTime());
};
export var _isValidBlob = function (blob) {
    return blob instanceof Blob;
};
export var _isValidFile = function (file) {
    return file instanceof File;
};
export var _isValidRegExp = function (regex) {
    return regex instanceof RegExp;
};
export var _isValidPromise = function (promise) {
    return promise instanceof Promise;
};
export var _isValidDateString = function (dateString) {
    return !isNaN(Date.parse(dateString));
};
export var _isValidHTMLElement = function (element) {
    return element instanceof HTMLElement;
};
export var _isValidEvent = function (event) {
    return event instanceof Event;
};
export var _isValidNode = function (node) {
    return node instanceof Node;
};
export var _isValidNodeList = function (nodeList) {
    return nodeList instanceof NodeList;
};
export var _isValidHTMLCollection = function (htmlCollection) {
    return htmlCollection instanceof HTMLCollection;
};
export var _isValidFormData = function (formData) {
    return formData instanceof FormData;
};
export var _isValidURLSearchParams = function (params) {
    return params instanceof URLSearchParams;
};
